=========
Changelog
=========

Version 0.3.0 - 2021-03-18
==========================

- Handle conversion of datetime objects (time, date, datetime) natively

Version 0.2.1 - 2021-03-15
==========================

- Ignore empty columns in gsheets

Version 0.2 - 2021-02-17
========================

- Added DB API 2.0 layer
- Added SQLAlchemy dialect
- Added Google Spreadsheets adapter
- Added drop-in replacement for gsheets:// dialect

Version 0.1 - 2020-10-26
========================

- Initial release
